<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Базово изтегляне</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Вземи списък</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Въведете URL адрес:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Изтегляне</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Код на формат</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Разширение</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Резолюция</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Забележка</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Име на Енджина:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Поставяне на съдържание от клипборда</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Наскоро използвани</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Задаване на опции за изтегляне</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Пакетно изтегляне</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Миниатюра</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL адрес за изтегляне</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Поставяне на URL адрес от клипборда</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Монитор на клипборда за URL адрес</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Добавяне на URL адрес към списъка</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Комплект</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Изтегляне на плейлисти</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Опции за изтегляне:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Начален час на времевия интервал (ЧЧ:ММ:СС):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Краен час на времевия интервал (ЧЧ:ММ:СС):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Глави (разделени със запетаи):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Разделено по глави</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скриване</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Въведете URL адрес на плейлиста:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Изчистване на вътрешния архивен файл</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Използване на вътрешен архивен файл</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Нагоре</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновяване</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Отвори папка</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Дом</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Конфигуриране</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Общи опции</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Показване на икона в системния трей</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Автоматично запазване на списъка с неизтеглени медийни файлове</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Автоматично скриване на изтеглянията след завършване</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Възстановяване на опцията до подразб</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Задаване на настройки по подразб</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Пресети</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Път за изтегляне</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Изберете език</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Използване на ръчно зададена конфигурация за прокси</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Получаване на конфигурация за прокси от средата</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Без прокси</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Запазване</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Опции по подразб. на Енджина</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Размер на файла</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Получаване на опции за списък:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Абонаменти</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Име потреб. интерфейс</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL адрес</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Активиране на раздела „Библиотека“</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Макс. брой едновремен. изтегляния</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Кодиране на текст</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Показване на информация за версията и автоматично изтегляне на актуализации</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Показване на информация за версията и информация за най-новата версия</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Показване само на информация за версията</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Не правете нищо</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Действия при стартиране</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Уебсайт</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Име на енджина</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По подразб</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Опции за добавяне</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Мениджър на URL адреси</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Опции за изтегляне</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Задайте кой URL адрес трябва да се управлява от коя машина</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Филтър за URL адреси</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Настройки за прокси</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Използване на конфигурацията на системния прокси сървър</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Ръчно зададена конфигурация на прокси</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Относно</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Възпроизвеждане на изтеглени медийни файлове</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Въведете URL адрес на плейлиста. За да добавите няколко плейлисти, разделете ги с интервал или нов ред</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Преименуване на файл на текст под него</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Бутон за отваряне на папка, която да се използва като папка за изтегляне</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Бутон за отваряне на папка, където се съхраняват файловете за конфигурация на темата</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Бутон за отваряне на папка, където се съхраняват двоичните файлове на разширението</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Сигурни ли сте, че искате да възстановите тези опции до фабричните им настройки?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Не</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Име на уеб браузъра, от който да се получават бисквитки</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation>Тема (Необходим е рестарт)</translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation>Превключване между задаване на име на браузъра и път до файла с бисквитки</translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation>Показване на метаданни в пакетното изтегляне</translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation>Автоматично изтегляне на добавени записи в пакетното изтегляне</translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation>Уведомяване при завършване на изтеглянето</translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation>Уведомяване, когато всички изтегляния завършат</translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation>Опции на енджина</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Разширения</translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation>Премахване на разширение</translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation>Актуализиране на разширение</translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation>Добавяне на разширение</translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation>Отваряне на двоична папка</translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 Пресети</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Име на файл с разширение &quot;.txt&quot; ще запазва само URL адреси</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Скриване на ред</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Показване на всички скрити редове</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Неуспешно стартиране на изпълним файл %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копиране на URL адрес</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Отваряне на URL адрес с %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Копиране на URL адрес %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Запазване на списъка във файл</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Отговори на</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Запазване на субтитрите във файл</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Име на енджина:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Получаване на списък от файл</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Пресети</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Изчисти</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Отваряне на папката за изтегляне</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Страница на проекта</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Авторско право</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лиценз</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Имейл</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Qt версия</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Тази програма е свободен софтуер; можете да я разпространявате и/или променяте съгласно условията на Общия публичен лиценз на GNU, публикуван от Фондацията за свободен софтуер; или версия 2 на Лиценза, или (по ваш избор) всяка по-късна версия.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Тази програма се разпространява с надеждата, че ще бъде полезна, но БЕЗ НИКАКВА ГАРАНЦИЯ; дори без подразбиращата се гаранция за ПРОДАВАЕМОСТ или ГОДНОСТ ЗА ОПРЕДЕЛЕНА ЦЕЛ. Вижте Общия публичен лиценз на GNU за повече подробности.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>полски (Полша)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Английски (САЩ)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Испански (Испания)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>китайски (Китай)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>турски (Турция)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>руски (Русия)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>японски (Япония)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>френски (Франция)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Италиански (Италия)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>шведски (Швеция)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Немски (Германия)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Португалски (Бразилия)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>нидерландски (Нидерландия)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Грешка, изпълним файл за бекенд &quot;%1&quot; не можа да бъде намерен</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Енджин „%1“ изисква поне версия „%2“ на Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>За да деактивирате тези проверки, направете следното: -</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Отидете на раздела „Конфигуриране“.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Отидете на подраздела „Общи опции“.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Кликнете върху менюто „Действия при стартиране“.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Изберете „Не правете нищо“.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Работи в портейбъл режим</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Работи в режим на инсталиране</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Път за изтегляне: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Път към данните на приложението: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Задаване на адрес на прокси сървъра на %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Премахване на адреса на прокси сървъра</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Грешка, неуспешно анализиране на конфигурационния файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Неуспешно зареждане на плъгин</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Неуспешно намиране на изпълним файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Неуспешно намиране на изпълним файл python3 за backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Възникна мрежова грешка</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>URL адресът не се поддържа</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Изтеглянето е отменено</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Код на грешката</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Изтеглянето не бе успешно, Енджина не стартира</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Изтеглянето не бе успешно, Енджина се срина</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Код на формата</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Разширение</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Резолюция</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Забележка</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Неуспешно отваряне на файл за запис</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Неуспешно отваряне на файла за четене</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Изминало време:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Неуспешно намиране на информация за версията. Уверете се, че &quot;%1&quot; е инсталиран и работи правилно</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Намерена версия</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Неуспешно отваряне на път за запис: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Неуспешно извличане</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Мрежата не успя да отговори в рамките на %1 секунди</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Изтеглянето не бе успешно, следният път не може да бъде създаден: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Започнете изтеглянето</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Проблем предстои, неуспешно изтриване на папка: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Неуспешно намиране на изпълним файл &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Изтеглянето не бе успешно</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Неуспешно анализиране на JSON файл от GitHub</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Изтегляне</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Дестинация</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Актуализацията е завършена, рестартирайте, за да използвате новата версия</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Защитен канал на Windows</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Файлът не е намерен</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Изтеглянето е завършено</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Извличане на архив: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Обработка</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Изтеглянето е завършено</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Възстановяване на папката за изтегляне до подразб</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Пост обработка</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Изтегляне</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Принудително изтегляне</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Показване на прозореца за лог</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Дата на качване:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Продължителност:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Име на субтитрите</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Опции за изтегляне</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Допълнителни опции за изтегляне</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Интервал от време за изтегляне</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Изтегляне на глави</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Разделено по глави</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Медийни файлове вече са в архива</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Тъмна</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Оставащо време</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Изтеглено</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 вече е изтеглен</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Това може да отнеме много време</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Скорост:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Има актуализация за %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Най-новата версия е %1, актуализира се</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Проверка на инсталираната версия на %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Намерена версия: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>Най-новата версия е: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Моля, актуализирайте &quot;%1&quot; поне до версия &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Заявеният формат не е наличен</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>Въведен е невалиден URL адрес</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Само най-добрият наличен аудио</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Само най-добрият наличен аудио (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Най-доброто налично аудио видео</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Най-добър звук с видео резолюция от %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Предупреждение: Пропускане на съдържанието на клипборда</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Покажи папките първо</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Подреждане във възходящ ред</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Подреди по дата</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Подреди по име</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Подреждане в низходящ ред</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Филтър</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Без филтър</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Други уебсайтове</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Извличане на аудио</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Извличане на аудио като MP3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Арабски</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Само най-добрият наличен звук + миниатюра</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Автоматичното актуализиране е деактивирано за %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>Най-новата версия е %1, автоматичното актуализиране е деактивирано</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Автор: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Брой харесвания: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Корейски (Корея)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Влезте, за да потвърдите, че не сте бот</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Показване/скриване на контроли</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Обединяване на аудио и видео</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Ремултиплексиране на видео</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation>гръцки (Гърция)</translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation>Платформа по подразб</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светла</translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation>Преименуването не бе успешно</translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation>Завършено: %1, Изпълнява се: %2, Не е започнато: %3, Успешно: %4, Неуспешно: %5, Отменено: %6</translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation>Спиране, защото медийният файл вече е в архивния файл</translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation>Български (България)</translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation>Отваряне на URL адреси с %2</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Плеер подразбиране</translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation>Внимание, нищо не е изтеглено</translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation>Изтеглянето е отменено, URL на плейлиста не са разрешени в този раздел</translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation>Изтеглянето е отменено, защото не е изпълнено условие</translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation>Изтеглянето не бе успешно, причината е неизвестна</translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation>Изтеглянето не бе успешно, проблем с мрежата</translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Скриване на списъка</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Задаване на пакетен файл</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отворено</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Изтегляне на коментари</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Изтегляне</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Запазване</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копиране на URL адрес</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Показване на субтитри</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Покажи коментари</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Показване на медийни опции</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Изтегляне на медийна част</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Комплект</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Изтегляне на субтитри</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Сортиране по дата във възходящ ред</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Сортиране по дата в низходящ ред</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Сортиране по харесвания</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Задай по подразб</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Изберете файл на Енджина</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Задаване на папка за изтегляне</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактиране</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Задаване на настройки по подразб</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation>Изберете файл с бисквитки</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Име на уеб браузъра, от който да се получават бисквитки</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation>Задаване на път до файла с бисквитки</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Изтрий всички</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Сигурни ли сте, че искате да изтриете файла по-долу?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Сигурни ли сте, че искате да изтриете папката по-долу?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Не</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Сигурни ли сте, че искате да изтриете всички файлове и папки?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Преименуване на файл на текст под него</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Преименуване на папка на „Под текста“</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Сигурни ли сте, че искате да изтриете избраните елементи?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Прозорец за дневник</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Изчисти</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Отворено</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Скриване на контролите</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Получаване на опции за списък:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Копиране на URL адрес</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Покажи коментари</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Покажи всички актуализирани</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Изтегляне на всички актуализирани</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Управление на абонаменти</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Брой изтеглени страници</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Изтегляне на информация за видеото</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Показване на контроли</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Покажи</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Скриване</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Това може да отнеме много време</translation>
    </message>
</context>
</TS>
